( cd etc/rc.d ; rm -rf rc.news )
( cd etc/rc.d ; ln -sf /usr/lib/news/bin/rc.news rc.news )
( cd usr/bin ; rm -rf inews )
( cd usr/bin ; ln -sf /usr/lib/news/bin/inews inews )
